# This file was automatically generated by SWIG (https://www.swig.org).
# Version 4.4.1
#
# Do not make changes to this file unless you know what you are doing - modify
# the SWIG interface file instead.


import collections

from sys import version_info as _version_info
if _version_info < (3, 7, 0):
    raise RuntimeError("Python 3.7 or later required")

from . import _ITKCommonPython


from . import _ITKImageStatisticsPython



from sys import version_info as _swig_python_version_info
# Import the low-level C/C++ module
if getattr(globals().get("__spec__"), "parent", None) or __package__ or "." in __name__:
    from . import _itkLabelStatisticsImageFilterPython
else:
    import _itkLabelStatisticsImageFilterPython

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "this":
            set(self, name, value)
        elif name == "thisown":
            self.this.own(value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


if _swig_python_version_info[0:2] >= (3, 3):
    import collections.abc
else:
    import collections

import itk.itkImagePython
import itk.itkImageRegionPython
import itk.ITKCommonBasePython
import itk.itkMatrixPython
import itk.itkPointPython
import itk.vnl_vectorPython
import itk.stdcomplexPython
import itk.pyBasePython
import itk.vnl_matrixPython
import itk.itkVectorPython
import itk.itkFixedArrayPython
import itk.vnl_vector_refPython
import itk.vnl_matrix_fixedPython
import itk.itkCovariantVectorPython
import itk.itkIndexPython
import itk.itkOffsetPython
import itk.itkSizePython
import itk.itkRGBAPixelPython
import itk.itkSymmetricSecondRankTensorPython
import itk.itkRGBPixelPython
import itk.itkImageSinkPython
import itk.itkImageToImageFilterCommonPython
import itk.itkVectorImagePython
import itk.itkVariableLengthVectorPython
import itk.itkHistogramPython
import itk.itkSamplePython
import itk.itkArrayPython

def itkLabelStatisticsImageFilterIF2ISS2_New():
    return itkLabelStatisticsImageFilterIF2ISS2.New()

class itkLabelStatisticsImageFilterIF2ISS2(itk.itkImageSinkPython.itkImageSinkIF2):
    r"""Proxy of C++ itkLabelStatisticsImageFilterIF2ISS2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkLabelStatisticsImageFilterIF2ISS2_Pointer"""
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterIF2ISS2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkLabelStatisticsImageFilterIF2ISS2_Pointer"""
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterIF2ISS2_Clone(self)

    def SetUseHistograms(self, _arg):
        r"""
        SetUseHistograms(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterIF2ISS2_SetUseHistograms(self, _arg)

    def GetUseHistograms(self):
        r"""GetUseHistograms(self) -> bool"""
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterIF2ISS2_GetUseHistograms(self)

    def UseHistogramsOn(self):
        r"""UseHistogramsOn(self)"""
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterIF2ISS2_UseHistogramsOn(self)

    def UseHistogramsOff(self):
        r"""UseHistogramsOff(self)"""
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterIF2ISS2_UseHistogramsOff(self)

    def GetValidLabelValues(self):
        r"""GetValidLabelValues(self) -> vectorSS"""
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterIF2ISS2_GetValidLabelValues(self)

    def SetLabelInput(self, _arg):
        r"""
        SetLabelInput(self, _arg)

        Parameters
        ----------
        _arg: itkImageSS2 const *

        """
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterIF2ISS2_SetLabelInput(self, _arg)

    def GetLabelInput(self):
        r"""GetLabelInput(self) -> itkImageSS2"""
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterIF2ISS2_GetLabelInput(self)

    def HasLabel(self, label):
        r"""
        HasLabel(self, label) -> bool

        Parameters
        ----------
        label: short

        """
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterIF2ISS2_HasLabel(self, label)

    def GetNumberOfObjects(self):
        r"""GetNumberOfObjects(self) -> unsigned long"""
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterIF2ISS2_GetNumberOfObjects(self)

    def GetNumberOfLabels(self):
        r"""GetNumberOfLabels(self) -> unsigned long"""
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterIF2ISS2_GetNumberOfLabels(self)

    def GetMinimum(self, label):
        r"""
        GetMinimum(self, label) -> double

        Parameters
        ----------
        label: short

        """
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterIF2ISS2_GetMinimum(self, label)

    def GetMaximum(self, label):
        r"""
        GetMaximum(self, label) -> double

        Parameters
        ----------
        label: short

        """
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterIF2ISS2_GetMaximum(self, label)

    def GetMean(self, label):
        r"""
        GetMean(self, label) -> double

        Parameters
        ----------
        label: short

        """
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterIF2ISS2_GetMean(self, label)

    def GetMedian(self, label):
        r"""
        GetMedian(self, label) -> double

        Parameters
        ----------
        label: short

        """
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterIF2ISS2_GetMedian(self, label)

    def GetSigma(self, label):
        r"""
        GetSigma(self, label) -> double

        Parameters
        ----------
        label: short

        """
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterIF2ISS2_GetSigma(self, label)

    def GetVariance(self, label):
        r"""
        GetVariance(self, label) -> double

        Parameters
        ----------
        label: short

        """
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterIF2ISS2_GetVariance(self, label)

    def GetBoundingBox(self, label):
        r"""
        GetBoundingBox(self, label) -> vectorSL

        Parameters
        ----------
        label: short

        """
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterIF2ISS2_GetBoundingBox(self, label)

    def GetRegion(self, label):
        r"""
        GetRegion(self, label) -> itkImageRegion2

        Parameters
        ----------
        label: short

        """
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterIF2ISS2_GetRegion(self, label)

    def GetSum(self, label):
        r"""
        GetSum(self, label) -> double

        Parameters
        ----------
        label: short

        """
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterIF2ISS2_GetSum(self, label)

    def GetCount(self, label):
        r"""
        GetCount(self, label) -> unsigned long

        Parameters
        ----------
        label: short

        """
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterIF2ISS2_GetCount(self, label)

    def GetHistogram(self, label):
        r"""
        GetHistogram(self, label) -> itkHistogramD_Pointer

        Parameters
        ----------
        label: short

        """
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterIF2ISS2_GetHistogram(self, label)

    def SetHistogramParameters(self, numBins, lowerBound, upperBound):
        r"""
        SetHistogramParameters(self, numBins, lowerBound, upperBound)

        Parameters
        ----------
        numBins: int const
        lowerBound: double
        upperBound: double

        """
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterIF2ISS2_SetHistogramParameters(self, numBins, lowerBound, upperBound)

    def SetNumberOfStreamDivisions(self, n):
        r"""
        SetNumberOfStreamDivisions(self, n)

        Parameters
        ----------
        n: unsigned int const

        """
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterIF2ISS2_SetNumberOfStreamDivisions(self, n)

    def GetNumberOfStreamDivisions(self):
        r"""GetNumberOfStreamDivisions(self) -> unsigned int"""
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterIF2ISS2_GetNumberOfStreamDivisions(self)
    InputHasNumericTraitsCheck = _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterIF2ISS2_InputHasNumericTraitsCheck
    
    __swig_destroy__ = _itkLabelStatisticsImageFilterPython.delete_itkLabelStatisticsImageFilterIF2ISS2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkLabelStatisticsImageFilterIF2ISS2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterIF2ISS2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkLabelStatisticsImageFilterIF2ISS2

        Create a new object of the class itkLabelStatisticsImageFilterIF2ISS2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkLabelStatisticsImageFilterIF2ISS2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkLabelStatisticsImageFilterIF2ISS2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkLabelStatisticsImageFilterIF2ISS2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkLabelStatisticsImageFilterIF2ISS2 in _itkLabelStatisticsImageFilterPython:
_itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterIF2ISS2_swigregister(itkLabelStatisticsImageFilterIF2ISS2)

def itkLabelStatisticsImageFilterIF2IUC2_New():
    return itkLabelStatisticsImageFilterIF2IUC2.New()

class itkLabelStatisticsImageFilterIF2IUC2(itk.itkImageSinkPython.itkImageSinkIF2):
    r"""Proxy of C++ itkLabelStatisticsImageFilterIF2IUC2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkLabelStatisticsImageFilterIF2IUC2_Pointer"""
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterIF2IUC2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkLabelStatisticsImageFilterIF2IUC2_Pointer"""
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterIF2IUC2_Clone(self)

    def SetUseHistograms(self, _arg):
        r"""
        SetUseHistograms(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterIF2IUC2_SetUseHistograms(self, _arg)

    def GetUseHistograms(self):
        r"""GetUseHistograms(self) -> bool"""
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterIF2IUC2_GetUseHistograms(self)

    def UseHistogramsOn(self):
        r"""UseHistogramsOn(self)"""
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterIF2IUC2_UseHistogramsOn(self)

    def UseHistogramsOff(self):
        r"""UseHistogramsOff(self)"""
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterIF2IUC2_UseHistogramsOff(self)

    def GetValidLabelValues(self):
        r"""GetValidLabelValues(self) -> vectorUC"""
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterIF2IUC2_GetValidLabelValues(self)

    def SetLabelInput(self, _arg):
        r"""
        SetLabelInput(self, _arg)

        Parameters
        ----------
        _arg: itkImageUC2 const *

        """
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterIF2IUC2_SetLabelInput(self, _arg)

    def GetLabelInput(self):
        r"""GetLabelInput(self) -> itkImageUC2"""
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterIF2IUC2_GetLabelInput(self)

    def HasLabel(self, label):
        r"""
        HasLabel(self, label) -> bool

        Parameters
        ----------
        label: unsigned char

        """
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterIF2IUC2_HasLabel(self, label)

    def GetNumberOfObjects(self):
        r"""GetNumberOfObjects(self) -> unsigned long"""
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterIF2IUC2_GetNumberOfObjects(self)

    def GetNumberOfLabels(self):
        r"""GetNumberOfLabels(self) -> unsigned long"""
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterIF2IUC2_GetNumberOfLabels(self)

    def GetMinimum(self, label):
        r"""
        GetMinimum(self, label) -> double

        Parameters
        ----------
        label: unsigned char

        """
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterIF2IUC2_GetMinimum(self, label)

    def GetMaximum(self, label):
        r"""
        GetMaximum(self, label) -> double

        Parameters
        ----------
        label: unsigned char

        """
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterIF2IUC2_GetMaximum(self, label)

    def GetMean(self, label):
        r"""
        GetMean(self, label) -> double

        Parameters
        ----------
        label: unsigned char

        """
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterIF2IUC2_GetMean(self, label)

    def GetMedian(self, label):
        r"""
        GetMedian(self, label) -> double

        Parameters
        ----------
        label: unsigned char

        """
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterIF2IUC2_GetMedian(self, label)

    def GetSigma(self, label):
        r"""
        GetSigma(self, label) -> double

        Parameters
        ----------
        label: unsigned char

        """
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterIF2IUC2_GetSigma(self, label)

    def GetVariance(self, label):
        r"""
        GetVariance(self, label) -> double

        Parameters
        ----------
        label: unsigned char

        """
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterIF2IUC2_GetVariance(self, label)

    def GetBoundingBox(self, label):
        r"""
        GetBoundingBox(self, label) -> vectorSL

        Parameters
        ----------
        label: unsigned char

        """
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterIF2IUC2_GetBoundingBox(self, label)

    def GetRegion(self, label):
        r"""
        GetRegion(self, label) -> itkImageRegion2

        Parameters
        ----------
        label: unsigned char

        """
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterIF2IUC2_GetRegion(self, label)

    def GetSum(self, label):
        r"""
        GetSum(self, label) -> double

        Parameters
        ----------
        label: unsigned char

        """
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterIF2IUC2_GetSum(self, label)

    def GetCount(self, label):
        r"""
        GetCount(self, label) -> unsigned long

        Parameters
        ----------
        label: unsigned char

        """
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterIF2IUC2_GetCount(self, label)

    def GetHistogram(self, label):
        r"""
        GetHistogram(self, label) -> itkHistogramD_Pointer

        Parameters
        ----------
        label: unsigned char

        """
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterIF2IUC2_GetHistogram(self, label)

    def SetHistogramParameters(self, numBins, lowerBound, upperBound):
        r"""
        SetHistogramParameters(self, numBins, lowerBound, upperBound)

        Parameters
        ----------
        numBins: int const
        lowerBound: double
        upperBound: double

        """
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterIF2IUC2_SetHistogramParameters(self, numBins, lowerBound, upperBound)

    def SetNumberOfStreamDivisions(self, n):
        r"""
        SetNumberOfStreamDivisions(self, n)

        Parameters
        ----------
        n: unsigned int const

        """
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterIF2IUC2_SetNumberOfStreamDivisions(self, n)

    def GetNumberOfStreamDivisions(self):
        r"""GetNumberOfStreamDivisions(self) -> unsigned int"""
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterIF2IUC2_GetNumberOfStreamDivisions(self)
    InputHasNumericTraitsCheck = _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterIF2IUC2_InputHasNumericTraitsCheck
    
    __swig_destroy__ = _itkLabelStatisticsImageFilterPython.delete_itkLabelStatisticsImageFilterIF2IUC2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkLabelStatisticsImageFilterIF2IUC2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterIF2IUC2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkLabelStatisticsImageFilterIF2IUC2

        Create a new object of the class itkLabelStatisticsImageFilterIF2IUC2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkLabelStatisticsImageFilterIF2IUC2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkLabelStatisticsImageFilterIF2IUC2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkLabelStatisticsImageFilterIF2IUC2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkLabelStatisticsImageFilterIF2IUC2 in _itkLabelStatisticsImageFilterPython:
_itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterIF2IUC2_swigregister(itkLabelStatisticsImageFilterIF2IUC2)

def itkLabelStatisticsImageFilterIF3ISS3_New():
    return itkLabelStatisticsImageFilterIF3ISS3.New()

class itkLabelStatisticsImageFilterIF3ISS3(itk.itkImageSinkPython.itkImageSinkIF3):
    r"""Proxy of C++ itkLabelStatisticsImageFilterIF3ISS3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkLabelStatisticsImageFilterIF3ISS3_Pointer"""
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterIF3ISS3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkLabelStatisticsImageFilterIF3ISS3_Pointer"""
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterIF3ISS3_Clone(self)

    def SetUseHistograms(self, _arg):
        r"""
        SetUseHistograms(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterIF3ISS3_SetUseHistograms(self, _arg)

    def GetUseHistograms(self):
        r"""GetUseHistograms(self) -> bool"""
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterIF3ISS3_GetUseHistograms(self)

    def UseHistogramsOn(self):
        r"""UseHistogramsOn(self)"""
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterIF3ISS3_UseHistogramsOn(self)

    def UseHistogramsOff(self):
        r"""UseHistogramsOff(self)"""
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterIF3ISS3_UseHistogramsOff(self)

    def GetValidLabelValues(self):
        r"""GetValidLabelValues(self) -> vectorSS"""
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterIF3ISS3_GetValidLabelValues(self)

    def SetLabelInput(self, _arg):
        r"""
        SetLabelInput(self, _arg)

        Parameters
        ----------
        _arg: itkImageSS3 const *

        """
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterIF3ISS3_SetLabelInput(self, _arg)

    def GetLabelInput(self):
        r"""GetLabelInput(self) -> itkImageSS3"""
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterIF3ISS3_GetLabelInput(self)

    def HasLabel(self, label):
        r"""
        HasLabel(self, label) -> bool

        Parameters
        ----------
        label: short

        """
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterIF3ISS3_HasLabel(self, label)

    def GetNumberOfObjects(self):
        r"""GetNumberOfObjects(self) -> unsigned long"""
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterIF3ISS3_GetNumberOfObjects(self)

    def GetNumberOfLabels(self):
        r"""GetNumberOfLabels(self) -> unsigned long"""
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterIF3ISS3_GetNumberOfLabels(self)

    def GetMinimum(self, label):
        r"""
        GetMinimum(self, label) -> double

        Parameters
        ----------
        label: short

        """
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterIF3ISS3_GetMinimum(self, label)

    def GetMaximum(self, label):
        r"""
        GetMaximum(self, label) -> double

        Parameters
        ----------
        label: short

        """
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterIF3ISS3_GetMaximum(self, label)

    def GetMean(self, label):
        r"""
        GetMean(self, label) -> double

        Parameters
        ----------
        label: short

        """
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterIF3ISS3_GetMean(self, label)

    def GetMedian(self, label):
        r"""
        GetMedian(self, label) -> double

        Parameters
        ----------
        label: short

        """
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterIF3ISS3_GetMedian(self, label)

    def GetSigma(self, label):
        r"""
        GetSigma(self, label) -> double

        Parameters
        ----------
        label: short

        """
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterIF3ISS3_GetSigma(self, label)

    def GetVariance(self, label):
        r"""
        GetVariance(self, label) -> double

        Parameters
        ----------
        label: short

        """
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterIF3ISS3_GetVariance(self, label)

    def GetBoundingBox(self, label):
        r"""
        GetBoundingBox(self, label) -> vectorSL

        Parameters
        ----------
        label: short

        """
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterIF3ISS3_GetBoundingBox(self, label)

    def GetRegion(self, label):
        r"""
        GetRegion(self, label) -> itkImageRegion3

        Parameters
        ----------
        label: short

        """
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterIF3ISS3_GetRegion(self, label)

    def GetSum(self, label):
        r"""
        GetSum(self, label) -> double

        Parameters
        ----------
        label: short

        """
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterIF3ISS3_GetSum(self, label)

    def GetCount(self, label):
        r"""
        GetCount(self, label) -> unsigned long

        Parameters
        ----------
        label: short

        """
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterIF3ISS3_GetCount(self, label)

    def GetHistogram(self, label):
        r"""
        GetHistogram(self, label) -> itkHistogramD_Pointer

        Parameters
        ----------
        label: short

        """
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterIF3ISS3_GetHistogram(self, label)

    def SetHistogramParameters(self, numBins, lowerBound, upperBound):
        r"""
        SetHistogramParameters(self, numBins, lowerBound, upperBound)

        Parameters
        ----------
        numBins: int const
        lowerBound: double
        upperBound: double

        """
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterIF3ISS3_SetHistogramParameters(self, numBins, lowerBound, upperBound)

    def SetNumberOfStreamDivisions(self, n):
        r"""
        SetNumberOfStreamDivisions(self, n)

        Parameters
        ----------
        n: unsigned int const

        """
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterIF3ISS3_SetNumberOfStreamDivisions(self, n)

    def GetNumberOfStreamDivisions(self):
        r"""GetNumberOfStreamDivisions(self) -> unsigned int"""
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterIF3ISS3_GetNumberOfStreamDivisions(self)
    InputHasNumericTraitsCheck = _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterIF3ISS3_InputHasNumericTraitsCheck
    
    __swig_destroy__ = _itkLabelStatisticsImageFilterPython.delete_itkLabelStatisticsImageFilterIF3ISS3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkLabelStatisticsImageFilterIF3ISS3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterIF3ISS3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkLabelStatisticsImageFilterIF3ISS3

        Create a new object of the class itkLabelStatisticsImageFilterIF3ISS3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkLabelStatisticsImageFilterIF3ISS3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkLabelStatisticsImageFilterIF3ISS3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkLabelStatisticsImageFilterIF3ISS3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkLabelStatisticsImageFilterIF3ISS3 in _itkLabelStatisticsImageFilterPython:
_itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterIF3ISS3_swigregister(itkLabelStatisticsImageFilterIF3ISS3)

def itkLabelStatisticsImageFilterIF3IUC3_New():
    return itkLabelStatisticsImageFilterIF3IUC3.New()

class itkLabelStatisticsImageFilterIF3IUC3(itk.itkImageSinkPython.itkImageSinkIF3):
    r"""Proxy of C++ itkLabelStatisticsImageFilterIF3IUC3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkLabelStatisticsImageFilterIF3IUC3_Pointer"""
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterIF3IUC3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkLabelStatisticsImageFilterIF3IUC3_Pointer"""
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterIF3IUC3_Clone(self)

    def SetUseHistograms(self, _arg):
        r"""
        SetUseHistograms(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterIF3IUC3_SetUseHistograms(self, _arg)

    def GetUseHistograms(self):
        r"""GetUseHistograms(self) -> bool"""
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterIF3IUC3_GetUseHistograms(self)

    def UseHistogramsOn(self):
        r"""UseHistogramsOn(self)"""
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterIF3IUC3_UseHistogramsOn(self)

    def UseHistogramsOff(self):
        r"""UseHistogramsOff(self)"""
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterIF3IUC3_UseHistogramsOff(self)

    def GetValidLabelValues(self):
        r"""GetValidLabelValues(self) -> vectorUC"""
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterIF3IUC3_GetValidLabelValues(self)

    def SetLabelInput(self, _arg):
        r"""
        SetLabelInput(self, _arg)

        Parameters
        ----------
        _arg: itkImageUC3 const *

        """
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterIF3IUC3_SetLabelInput(self, _arg)

    def GetLabelInput(self):
        r"""GetLabelInput(self) -> itkImageUC3"""
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterIF3IUC3_GetLabelInput(self)

    def HasLabel(self, label):
        r"""
        HasLabel(self, label) -> bool

        Parameters
        ----------
        label: unsigned char

        """
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterIF3IUC3_HasLabel(self, label)

    def GetNumberOfObjects(self):
        r"""GetNumberOfObjects(self) -> unsigned long"""
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterIF3IUC3_GetNumberOfObjects(self)

    def GetNumberOfLabels(self):
        r"""GetNumberOfLabels(self) -> unsigned long"""
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterIF3IUC3_GetNumberOfLabels(self)

    def GetMinimum(self, label):
        r"""
        GetMinimum(self, label) -> double

        Parameters
        ----------
        label: unsigned char

        """
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterIF3IUC3_GetMinimum(self, label)

    def GetMaximum(self, label):
        r"""
        GetMaximum(self, label) -> double

        Parameters
        ----------
        label: unsigned char

        """
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterIF3IUC3_GetMaximum(self, label)

    def GetMean(self, label):
        r"""
        GetMean(self, label) -> double

        Parameters
        ----------
        label: unsigned char

        """
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterIF3IUC3_GetMean(self, label)

    def GetMedian(self, label):
        r"""
        GetMedian(self, label) -> double

        Parameters
        ----------
        label: unsigned char

        """
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterIF3IUC3_GetMedian(self, label)

    def GetSigma(self, label):
        r"""
        GetSigma(self, label) -> double

        Parameters
        ----------
        label: unsigned char

        """
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterIF3IUC3_GetSigma(self, label)

    def GetVariance(self, label):
        r"""
        GetVariance(self, label) -> double

        Parameters
        ----------
        label: unsigned char

        """
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterIF3IUC3_GetVariance(self, label)

    def GetBoundingBox(self, label):
        r"""
        GetBoundingBox(self, label) -> vectorSL

        Parameters
        ----------
        label: unsigned char

        """
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterIF3IUC3_GetBoundingBox(self, label)

    def GetRegion(self, label):
        r"""
        GetRegion(self, label) -> itkImageRegion3

        Parameters
        ----------
        label: unsigned char

        """
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterIF3IUC3_GetRegion(self, label)

    def GetSum(self, label):
        r"""
        GetSum(self, label) -> double

        Parameters
        ----------
        label: unsigned char

        """
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterIF3IUC3_GetSum(self, label)

    def GetCount(self, label):
        r"""
        GetCount(self, label) -> unsigned long

        Parameters
        ----------
        label: unsigned char

        """
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterIF3IUC3_GetCount(self, label)

    def GetHistogram(self, label):
        r"""
        GetHistogram(self, label) -> itkHistogramD_Pointer

        Parameters
        ----------
        label: unsigned char

        """
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterIF3IUC3_GetHistogram(self, label)

    def SetHistogramParameters(self, numBins, lowerBound, upperBound):
        r"""
        SetHistogramParameters(self, numBins, lowerBound, upperBound)

        Parameters
        ----------
        numBins: int const
        lowerBound: double
        upperBound: double

        """
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterIF3IUC3_SetHistogramParameters(self, numBins, lowerBound, upperBound)

    def SetNumberOfStreamDivisions(self, n):
        r"""
        SetNumberOfStreamDivisions(self, n)

        Parameters
        ----------
        n: unsigned int const

        """
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterIF3IUC3_SetNumberOfStreamDivisions(self, n)

    def GetNumberOfStreamDivisions(self):
        r"""GetNumberOfStreamDivisions(self) -> unsigned int"""
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterIF3IUC3_GetNumberOfStreamDivisions(self)
    InputHasNumericTraitsCheck = _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterIF3IUC3_InputHasNumericTraitsCheck
    
    __swig_destroy__ = _itkLabelStatisticsImageFilterPython.delete_itkLabelStatisticsImageFilterIF3IUC3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkLabelStatisticsImageFilterIF3IUC3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterIF3IUC3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkLabelStatisticsImageFilterIF3IUC3

        Create a new object of the class itkLabelStatisticsImageFilterIF3IUC3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkLabelStatisticsImageFilterIF3IUC3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkLabelStatisticsImageFilterIF3IUC3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkLabelStatisticsImageFilterIF3IUC3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkLabelStatisticsImageFilterIF3IUC3 in _itkLabelStatisticsImageFilterPython:
_itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterIF3IUC3_swigregister(itkLabelStatisticsImageFilterIF3IUC3)

def itkLabelStatisticsImageFilterISS2ISS2_New():
    return itkLabelStatisticsImageFilterISS2ISS2.New()

class itkLabelStatisticsImageFilterISS2ISS2(itk.itkImageSinkPython.itkImageSinkISS2):
    r"""Proxy of C++ itkLabelStatisticsImageFilterISS2ISS2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkLabelStatisticsImageFilterISS2ISS2_Pointer"""
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterISS2ISS2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkLabelStatisticsImageFilterISS2ISS2_Pointer"""
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterISS2ISS2_Clone(self)

    def SetUseHistograms(self, _arg):
        r"""
        SetUseHistograms(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterISS2ISS2_SetUseHistograms(self, _arg)

    def GetUseHistograms(self):
        r"""GetUseHistograms(self) -> bool"""
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterISS2ISS2_GetUseHistograms(self)

    def UseHistogramsOn(self):
        r"""UseHistogramsOn(self)"""
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterISS2ISS2_UseHistogramsOn(self)

    def UseHistogramsOff(self):
        r"""UseHistogramsOff(self)"""
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterISS2ISS2_UseHistogramsOff(self)

    def GetValidLabelValues(self):
        r"""GetValidLabelValues(self) -> vectorSS"""
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterISS2ISS2_GetValidLabelValues(self)

    def SetLabelInput(self, _arg):
        r"""
        SetLabelInput(self, _arg)

        Parameters
        ----------
        _arg: itkImageSS2 const *

        """
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterISS2ISS2_SetLabelInput(self, _arg)

    def GetLabelInput(self):
        r"""GetLabelInput(self) -> itkImageSS2"""
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterISS2ISS2_GetLabelInput(self)

    def HasLabel(self, label):
        r"""
        HasLabel(self, label) -> bool

        Parameters
        ----------
        label: short

        """
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterISS2ISS2_HasLabel(self, label)

    def GetNumberOfObjects(self):
        r"""GetNumberOfObjects(self) -> unsigned long"""
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterISS2ISS2_GetNumberOfObjects(self)

    def GetNumberOfLabels(self):
        r"""GetNumberOfLabels(self) -> unsigned long"""
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterISS2ISS2_GetNumberOfLabels(self)

    def GetMinimum(self, label):
        r"""
        GetMinimum(self, label) -> double

        Parameters
        ----------
        label: short

        """
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterISS2ISS2_GetMinimum(self, label)

    def GetMaximum(self, label):
        r"""
        GetMaximum(self, label) -> double

        Parameters
        ----------
        label: short

        """
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterISS2ISS2_GetMaximum(self, label)

    def GetMean(self, label):
        r"""
        GetMean(self, label) -> double

        Parameters
        ----------
        label: short

        """
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterISS2ISS2_GetMean(self, label)

    def GetMedian(self, label):
        r"""
        GetMedian(self, label) -> double

        Parameters
        ----------
        label: short

        """
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterISS2ISS2_GetMedian(self, label)

    def GetSigma(self, label):
        r"""
        GetSigma(self, label) -> double

        Parameters
        ----------
        label: short

        """
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterISS2ISS2_GetSigma(self, label)

    def GetVariance(self, label):
        r"""
        GetVariance(self, label) -> double

        Parameters
        ----------
        label: short

        """
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterISS2ISS2_GetVariance(self, label)

    def GetBoundingBox(self, label):
        r"""
        GetBoundingBox(self, label) -> vectorSL

        Parameters
        ----------
        label: short

        """
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterISS2ISS2_GetBoundingBox(self, label)

    def GetRegion(self, label):
        r"""
        GetRegion(self, label) -> itkImageRegion2

        Parameters
        ----------
        label: short

        """
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterISS2ISS2_GetRegion(self, label)

    def GetSum(self, label):
        r"""
        GetSum(self, label) -> double

        Parameters
        ----------
        label: short

        """
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterISS2ISS2_GetSum(self, label)

    def GetCount(self, label):
        r"""
        GetCount(self, label) -> unsigned long

        Parameters
        ----------
        label: short

        """
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterISS2ISS2_GetCount(self, label)

    def GetHistogram(self, label):
        r"""
        GetHistogram(self, label) -> itkHistogramD_Pointer

        Parameters
        ----------
        label: short

        """
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterISS2ISS2_GetHistogram(self, label)

    def SetHistogramParameters(self, numBins, lowerBound, upperBound):
        r"""
        SetHistogramParameters(self, numBins, lowerBound, upperBound)

        Parameters
        ----------
        numBins: int const
        lowerBound: double
        upperBound: double

        """
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterISS2ISS2_SetHistogramParameters(self, numBins, lowerBound, upperBound)

    def SetNumberOfStreamDivisions(self, n):
        r"""
        SetNumberOfStreamDivisions(self, n)

        Parameters
        ----------
        n: unsigned int const

        """
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterISS2ISS2_SetNumberOfStreamDivisions(self, n)

    def GetNumberOfStreamDivisions(self):
        r"""GetNumberOfStreamDivisions(self) -> unsigned int"""
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterISS2ISS2_GetNumberOfStreamDivisions(self)
    InputHasNumericTraitsCheck = _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterISS2ISS2_InputHasNumericTraitsCheck
    
    __swig_destroy__ = _itkLabelStatisticsImageFilterPython.delete_itkLabelStatisticsImageFilterISS2ISS2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkLabelStatisticsImageFilterISS2ISS2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterISS2ISS2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkLabelStatisticsImageFilterISS2ISS2

        Create a new object of the class itkLabelStatisticsImageFilterISS2ISS2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkLabelStatisticsImageFilterISS2ISS2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkLabelStatisticsImageFilterISS2ISS2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkLabelStatisticsImageFilterISS2ISS2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkLabelStatisticsImageFilterISS2ISS2 in _itkLabelStatisticsImageFilterPython:
_itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterISS2ISS2_swigregister(itkLabelStatisticsImageFilterISS2ISS2)

def itkLabelStatisticsImageFilterISS2IUC2_New():
    return itkLabelStatisticsImageFilterISS2IUC2.New()

class itkLabelStatisticsImageFilterISS2IUC2(itk.itkImageSinkPython.itkImageSinkISS2):
    r"""Proxy of C++ itkLabelStatisticsImageFilterISS2IUC2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkLabelStatisticsImageFilterISS2IUC2_Pointer"""
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterISS2IUC2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkLabelStatisticsImageFilterISS2IUC2_Pointer"""
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterISS2IUC2_Clone(self)

    def SetUseHistograms(self, _arg):
        r"""
        SetUseHistograms(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterISS2IUC2_SetUseHistograms(self, _arg)

    def GetUseHistograms(self):
        r"""GetUseHistograms(self) -> bool"""
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterISS2IUC2_GetUseHistograms(self)

    def UseHistogramsOn(self):
        r"""UseHistogramsOn(self)"""
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterISS2IUC2_UseHistogramsOn(self)

    def UseHistogramsOff(self):
        r"""UseHistogramsOff(self)"""
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterISS2IUC2_UseHistogramsOff(self)

    def GetValidLabelValues(self):
        r"""GetValidLabelValues(self) -> vectorUC"""
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterISS2IUC2_GetValidLabelValues(self)

    def SetLabelInput(self, _arg):
        r"""
        SetLabelInput(self, _arg)

        Parameters
        ----------
        _arg: itkImageUC2 const *

        """
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterISS2IUC2_SetLabelInput(self, _arg)

    def GetLabelInput(self):
        r"""GetLabelInput(self) -> itkImageUC2"""
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterISS2IUC2_GetLabelInput(self)

    def HasLabel(self, label):
        r"""
        HasLabel(self, label) -> bool

        Parameters
        ----------
        label: unsigned char

        """
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterISS2IUC2_HasLabel(self, label)

    def GetNumberOfObjects(self):
        r"""GetNumberOfObjects(self) -> unsigned long"""
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterISS2IUC2_GetNumberOfObjects(self)

    def GetNumberOfLabels(self):
        r"""GetNumberOfLabels(self) -> unsigned long"""
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterISS2IUC2_GetNumberOfLabels(self)

    def GetMinimum(self, label):
        r"""
        GetMinimum(self, label) -> double

        Parameters
        ----------
        label: unsigned char

        """
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterISS2IUC2_GetMinimum(self, label)

    def GetMaximum(self, label):
        r"""
        GetMaximum(self, label) -> double

        Parameters
        ----------
        label: unsigned char

        """
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterISS2IUC2_GetMaximum(self, label)

    def GetMean(self, label):
        r"""
        GetMean(self, label) -> double

        Parameters
        ----------
        label: unsigned char

        """
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterISS2IUC2_GetMean(self, label)

    def GetMedian(self, label):
        r"""
        GetMedian(self, label) -> double

        Parameters
        ----------
        label: unsigned char

        """
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterISS2IUC2_GetMedian(self, label)

    def GetSigma(self, label):
        r"""
        GetSigma(self, label) -> double

        Parameters
        ----------
        label: unsigned char

        """
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterISS2IUC2_GetSigma(self, label)

    def GetVariance(self, label):
        r"""
        GetVariance(self, label) -> double

        Parameters
        ----------
        label: unsigned char

        """
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterISS2IUC2_GetVariance(self, label)

    def GetBoundingBox(self, label):
        r"""
        GetBoundingBox(self, label) -> vectorSL

        Parameters
        ----------
        label: unsigned char

        """
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterISS2IUC2_GetBoundingBox(self, label)

    def GetRegion(self, label):
        r"""
        GetRegion(self, label) -> itkImageRegion2

        Parameters
        ----------
        label: unsigned char

        """
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterISS2IUC2_GetRegion(self, label)

    def GetSum(self, label):
        r"""
        GetSum(self, label) -> double

        Parameters
        ----------
        label: unsigned char

        """
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterISS2IUC2_GetSum(self, label)

    def GetCount(self, label):
        r"""
        GetCount(self, label) -> unsigned long

        Parameters
        ----------
        label: unsigned char

        """
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterISS2IUC2_GetCount(self, label)

    def GetHistogram(self, label):
        r"""
        GetHistogram(self, label) -> itkHistogramD_Pointer

        Parameters
        ----------
        label: unsigned char

        """
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterISS2IUC2_GetHistogram(self, label)

    def SetHistogramParameters(self, numBins, lowerBound, upperBound):
        r"""
        SetHistogramParameters(self, numBins, lowerBound, upperBound)

        Parameters
        ----------
        numBins: int const
        lowerBound: double
        upperBound: double

        """
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterISS2IUC2_SetHistogramParameters(self, numBins, lowerBound, upperBound)

    def SetNumberOfStreamDivisions(self, n):
        r"""
        SetNumberOfStreamDivisions(self, n)

        Parameters
        ----------
        n: unsigned int const

        """
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterISS2IUC2_SetNumberOfStreamDivisions(self, n)

    def GetNumberOfStreamDivisions(self):
        r"""GetNumberOfStreamDivisions(self) -> unsigned int"""
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterISS2IUC2_GetNumberOfStreamDivisions(self)
    InputHasNumericTraitsCheck = _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterISS2IUC2_InputHasNumericTraitsCheck
    
    __swig_destroy__ = _itkLabelStatisticsImageFilterPython.delete_itkLabelStatisticsImageFilterISS2IUC2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkLabelStatisticsImageFilterISS2IUC2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterISS2IUC2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkLabelStatisticsImageFilterISS2IUC2

        Create a new object of the class itkLabelStatisticsImageFilterISS2IUC2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkLabelStatisticsImageFilterISS2IUC2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkLabelStatisticsImageFilterISS2IUC2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkLabelStatisticsImageFilterISS2IUC2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkLabelStatisticsImageFilterISS2IUC2 in _itkLabelStatisticsImageFilterPython:
_itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterISS2IUC2_swigregister(itkLabelStatisticsImageFilterISS2IUC2)

def itkLabelStatisticsImageFilterISS3ISS3_New():
    return itkLabelStatisticsImageFilterISS3ISS3.New()

class itkLabelStatisticsImageFilterISS3ISS3(itk.itkImageSinkPython.itkImageSinkISS3):
    r"""Proxy of C++ itkLabelStatisticsImageFilterISS3ISS3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkLabelStatisticsImageFilterISS3ISS3_Pointer"""
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterISS3ISS3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkLabelStatisticsImageFilterISS3ISS3_Pointer"""
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterISS3ISS3_Clone(self)

    def SetUseHistograms(self, _arg):
        r"""
        SetUseHistograms(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterISS3ISS3_SetUseHistograms(self, _arg)

    def GetUseHistograms(self):
        r"""GetUseHistograms(self) -> bool"""
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterISS3ISS3_GetUseHistograms(self)

    def UseHistogramsOn(self):
        r"""UseHistogramsOn(self)"""
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterISS3ISS3_UseHistogramsOn(self)

    def UseHistogramsOff(self):
        r"""UseHistogramsOff(self)"""
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterISS3ISS3_UseHistogramsOff(self)

    def GetValidLabelValues(self):
        r"""GetValidLabelValues(self) -> vectorSS"""
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterISS3ISS3_GetValidLabelValues(self)

    def SetLabelInput(self, _arg):
        r"""
        SetLabelInput(self, _arg)

        Parameters
        ----------
        _arg: itkImageSS3 const *

        """
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterISS3ISS3_SetLabelInput(self, _arg)

    def GetLabelInput(self):
        r"""GetLabelInput(self) -> itkImageSS3"""
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterISS3ISS3_GetLabelInput(self)

    def HasLabel(self, label):
        r"""
        HasLabel(self, label) -> bool

        Parameters
        ----------
        label: short

        """
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterISS3ISS3_HasLabel(self, label)

    def GetNumberOfObjects(self):
        r"""GetNumberOfObjects(self) -> unsigned long"""
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterISS3ISS3_GetNumberOfObjects(self)

    def GetNumberOfLabels(self):
        r"""GetNumberOfLabels(self) -> unsigned long"""
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterISS3ISS3_GetNumberOfLabels(self)

    def GetMinimum(self, label):
        r"""
        GetMinimum(self, label) -> double

        Parameters
        ----------
        label: short

        """
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterISS3ISS3_GetMinimum(self, label)

    def GetMaximum(self, label):
        r"""
        GetMaximum(self, label) -> double

        Parameters
        ----------
        label: short

        """
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterISS3ISS3_GetMaximum(self, label)

    def GetMean(self, label):
        r"""
        GetMean(self, label) -> double

        Parameters
        ----------
        label: short

        """
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterISS3ISS3_GetMean(self, label)

    def GetMedian(self, label):
        r"""
        GetMedian(self, label) -> double

        Parameters
        ----------
        label: short

        """
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterISS3ISS3_GetMedian(self, label)

    def GetSigma(self, label):
        r"""
        GetSigma(self, label) -> double

        Parameters
        ----------
        label: short

        """
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterISS3ISS3_GetSigma(self, label)

    def GetVariance(self, label):
        r"""
        GetVariance(self, label) -> double

        Parameters
        ----------
        label: short

        """
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterISS3ISS3_GetVariance(self, label)

    def GetBoundingBox(self, label):
        r"""
        GetBoundingBox(self, label) -> vectorSL

        Parameters
        ----------
        label: short

        """
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterISS3ISS3_GetBoundingBox(self, label)

    def GetRegion(self, label):
        r"""
        GetRegion(self, label) -> itkImageRegion3

        Parameters
        ----------
        label: short

        """
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterISS3ISS3_GetRegion(self, label)

    def GetSum(self, label):
        r"""
        GetSum(self, label) -> double

        Parameters
        ----------
        label: short

        """
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterISS3ISS3_GetSum(self, label)

    def GetCount(self, label):
        r"""
        GetCount(self, label) -> unsigned long

        Parameters
        ----------
        label: short

        """
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterISS3ISS3_GetCount(self, label)

    def GetHistogram(self, label):
        r"""
        GetHistogram(self, label) -> itkHistogramD_Pointer

        Parameters
        ----------
        label: short

        """
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterISS3ISS3_GetHistogram(self, label)

    def SetHistogramParameters(self, numBins, lowerBound, upperBound):
        r"""
        SetHistogramParameters(self, numBins, lowerBound, upperBound)

        Parameters
        ----------
        numBins: int const
        lowerBound: double
        upperBound: double

        """
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterISS3ISS3_SetHistogramParameters(self, numBins, lowerBound, upperBound)

    def SetNumberOfStreamDivisions(self, n):
        r"""
        SetNumberOfStreamDivisions(self, n)

        Parameters
        ----------
        n: unsigned int const

        """
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterISS3ISS3_SetNumberOfStreamDivisions(self, n)

    def GetNumberOfStreamDivisions(self):
        r"""GetNumberOfStreamDivisions(self) -> unsigned int"""
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterISS3ISS3_GetNumberOfStreamDivisions(self)
    InputHasNumericTraitsCheck = _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterISS3ISS3_InputHasNumericTraitsCheck
    
    __swig_destroy__ = _itkLabelStatisticsImageFilterPython.delete_itkLabelStatisticsImageFilterISS3ISS3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkLabelStatisticsImageFilterISS3ISS3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterISS3ISS3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkLabelStatisticsImageFilterISS3ISS3

        Create a new object of the class itkLabelStatisticsImageFilterISS3ISS3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkLabelStatisticsImageFilterISS3ISS3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkLabelStatisticsImageFilterISS3ISS3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkLabelStatisticsImageFilterISS3ISS3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkLabelStatisticsImageFilterISS3ISS3 in _itkLabelStatisticsImageFilterPython:
_itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterISS3ISS3_swigregister(itkLabelStatisticsImageFilterISS3ISS3)

def itkLabelStatisticsImageFilterISS3IUC3_New():
    return itkLabelStatisticsImageFilterISS3IUC3.New()

class itkLabelStatisticsImageFilterISS3IUC3(itk.itkImageSinkPython.itkImageSinkISS3):
    r"""Proxy of C++ itkLabelStatisticsImageFilterISS3IUC3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkLabelStatisticsImageFilterISS3IUC3_Pointer"""
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterISS3IUC3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkLabelStatisticsImageFilterISS3IUC3_Pointer"""
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterISS3IUC3_Clone(self)

    def SetUseHistograms(self, _arg):
        r"""
        SetUseHistograms(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterISS3IUC3_SetUseHistograms(self, _arg)

    def GetUseHistograms(self):
        r"""GetUseHistograms(self) -> bool"""
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterISS3IUC3_GetUseHistograms(self)

    def UseHistogramsOn(self):
        r"""UseHistogramsOn(self)"""
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterISS3IUC3_UseHistogramsOn(self)

    def UseHistogramsOff(self):
        r"""UseHistogramsOff(self)"""
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterISS3IUC3_UseHistogramsOff(self)

    def GetValidLabelValues(self):
        r"""GetValidLabelValues(self) -> vectorUC"""
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterISS3IUC3_GetValidLabelValues(self)

    def SetLabelInput(self, _arg):
        r"""
        SetLabelInput(self, _arg)

        Parameters
        ----------
        _arg: itkImageUC3 const *

        """
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterISS3IUC3_SetLabelInput(self, _arg)

    def GetLabelInput(self):
        r"""GetLabelInput(self) -> itkImageUC3"""
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterISS3IUC3_GetLabelInput(self)

    def HasLabel(self, label):
        r"""
        HasLabel(self, label) -> bool

        Parameters
        ----------
        label: unsigned char

        """
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterISS3IUC3_HasLabel(self, label)

    def GetNumberOfObjects(self):
        r"""GetNumberOfObjects(self) -> unsigned long"""
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterISS3IUC3_GetNumberOfObjects(self)

    def GetNumberOfLabels(self):
        r"""GetNumberOfLabels(self) -> unsigned long"""
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterISS3IUC3_GetNumberOfLabels(self)

    def GetMinimum(self, label):
        r"""
        GetMinimum(self, label) -> double

        Parameters
        ----------
        label: unsigned char

        """
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterISS3IUC3_GetMinimum(self, label)

    def GetMaximum(self, label):
        r"""
        GetMaximum(self, label) -> double

        Parameters
        ----------
        label: unsigned char

        """
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterISS3IUC3_GetMaximum(self, label)

    def GetMean(self, label):
        r"""
        GetMean(self, label) -> double

        Parameters
        ----------
        label: unsigned char

        """
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterISS3IUC3_GetMean(self, label)

    def GetMedian(self, label):
        r"""
        GetMedian(self, label) -> double

        Parameters
        ----------
        label: unsigned char

        """
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterISS3IUC3_GetMedian(self, label)

    def GetSigma(self, label):
        r"""
        GetSigma(self, label) -> double

        Parameters
        ----------
        label: unsigned char

        """
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterISS3IUC3_GetSigma(self, label)

    def GetVariance(self, label):
        r"""
        GetVariance(self, label) -> double

        Parameters
        ----------
        label: unsigned char

        """
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterISS3IUC3_GetVariance(self, label)

    def GetBoundingBox(self, label):
        r"""
        GetBoundingBox(self, label) -> vectorSL

        Parameters
        ----------
        label: unsigned char

        """
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterISS3IUC3_GetBoundingBox(self, label)

    def GetRegion(self, label):
        r"""
        GetRegion(self, label) -> itkImageRegion3

        Parameters
        ----------
        label: unsigned char

        """
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterISS3IUC3_GetRegion(self, label)

    def GetSum(self, label):
        r"""
        GetSum(self, label) -> double

        Parameters
        ----------
        label: unsigned char

        """
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterISS3IUC3_GetSum(self, label)

    def GetCount(self, label):
        r"""
        GetCount(self, label) -> unsigned long

        Parameters
        ----------
        label: unsigned char

        """
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterISS3IUC3_GetCount(self, label)

    def GetHistogram(self, label):
        r"""
        GetHistogram(self, label) -> itkHistogramD_Pointer

        Parameters
        ----------
        label: unsigned char

        """
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterISS3IUC3_GetHistogram(self, label)

    def SetHistogramParameters(self, numBins, lowerBound, upperBound):
        r"""
        SetHistogramParameters(self, numBins, lowerBound, upperBound)

        Parameters
        ----------
        numBins: int const
        lowerBound: double
        upperBound: double

        """
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterISS3IUC3_SetHistogramParameters(self, numBins, lowerBound, upperBound)

    def SetNumberOfStreamDivisions(self, n):
        r"""
        SetNumberOfStreamDivisions(self, n)

        Parameters
        ----------
        n: unsigned int const

        """
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterISS3IUC3_SetNumberOfStreamDivisions(self, n)

    def GetNumberOfStreamDivisions(self):
        r"""GetNumberOfStreamDivisions(self) -> unsigned int"""
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterISS3IUC3_GetNumberOfStreamDivisions(self)
    InputHasNumericTraitsCheck = _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterISS3IUC3_InputHasNumericTraitsCheck
    
    __swig_destroy__ = _itkLabelStatisticsImageFilterPython.delete_itkLabelStatisticsImageFilterISS3IUC3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkLabelStatisticsImageFilterISS3IUC3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterISS3IUC3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkLabelStatisticsImageFilterISS3IUC3

        Create a new object of the class itkLabelStatisticsImageFilterISS3IUC3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkLabelStatisticsImageFilterISS3IUC3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkLabelStatisticsImageFilterISS3IUC3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkLabelStatisticsImageFilterISS3IUC3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkLabelStatisticsImageFilterISS3IUC3 in _itkLabelStatisticsImageFilterPython:
_itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterISS3IUC3_swigregister(itkLabelStatisticsImageFilterISS3IUC3)

def itkLabelStatisticsImageFilterIUC2ISS2_New():
    return itkLabelStatisticsImageFilterIUC2ISS2.New()

class itkLabelStatisticsImageFilterIUC2ISS2(itk.itkImageSinkPython.itkImageSinkIUC2):
    r"""Proxy of C++ itkLabelStatisticsImageFilterIUC2ISS2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkLabelStatisticsImageFilterIUC2ISS2_Pointer"""
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterIUC2ISS2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkLabelStatisticsImageFilterIUC2ISS2_Pointer"""
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterIUC2ISS2_Clone(self)

    def SetUseHistograms(self, _arg):
        r"""
        SetUseHistograms(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterIUC2ISS2_SetUseHistograms(self, _arg)

    def GetUseHistograms(self):
        r"""GetUseHistograms(self) -> bool"""
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterIUC2ISS2_GetUseHistograms(self)

    def UseHistogramsOn(self):
        r"""UseHistogramsOn(self)"""
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterIUC2ISS2_UseHistogramsOn(self)

    def UseHistogramsOff(self):
        r"""UseHistogramsOff(self)"""
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterIUC2ISS2_UseHistogramsOff(self)

    def GetValidLabelValues(self):
        r"""GetValidLabelValues(self) -> vectorSS"""
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterIUC2ISS2_GetValidLabelValues(self)

    def SetLabelInput(self, _arg):
        r"""
        SetLabelInput(self, _arg)

        Parameters
        ----------
        _arg: itkImageSS2 const *

        """
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterIUC2ISS2_SetLabelInput(self, _arg)

    def GetLabelInput(self):
        r"""GetLabelInput(self) -> itkImageSS2"""
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterIUC2ISS2_GetLabelInput(self)

    def HasLabel(self, label):
        r"""
        HasLabel(self, label) -> bool

        Parameters
        ----------
        label: short

        """
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterIUC2ISS2_HasLabel(self, label)

    def GetNumberOfObjects(self):
        r"""GetNumberOfObjects(self) -> unsigned long"""
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterIUC2ISS2_GetNumberOfObjects(self)

    def GetNumberOfLabels(self):
        r"""GetNumberOfLabels(self) -> unsigned long"""
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterIUC2ISS2_GetNumberOfLabels(self)

    def GetMinimum(self, label):
        r"""
        GetMinimum(self, label) -> double

        Parameters
        ----------
        label: short

        """
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterIUC2ISS2_GetMinimum(self, label)

    def GetMaximum(self, label):
        r"""
        GetMaximum(self, label) -> double

        Parameters
        ----------
        label: short

        """
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterIUC2ISS2_GetMaximum(self, label)

    def GetMean(self, label):
        r"""
        GetMean(self, label) -> double

        Parameters
        ----------
        label: short

        """
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterIUC2ISS2_GetMean(self, label)

    def GetMedian(self, label):
        r"""
        GetMedian(self, label) -> double

        Parameters
        ----------
        label: short

        """
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterIUC2ISS2_GetMedian(self, label)

    def GetSigma(self, label):
        r"""
        GetSigma(self, label) -> double

        Parameters
        ----------
        label: short

        """
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterIUC2ISS2_GetSigma(self, label)

    def GetVariance(self, label):
        r"""
        GetVariance(self, label) -> double

        Parameters
        ----------
        label: short

        """
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterIUC2ISS2_GetVariance(self, label)

    def GetBoundingBox(self, label):
        r"""
        GetBoundingBox(self, label) -> vectorSL

        Parameters
        ----------
        label: short

        """
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterIUC2ISS2_GetBoundingBox(self, label)

    def GetRegion(self, label):
        r"""
        GetRegion(self, label) -> itkImageRegion2

        Parameters
        ----------
        label: short

        """
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterIUC2ISS2_GetRegion(self, label)

    def GetSum(self, label):
        r"""
        GetSum(self, label) -> double

        Parameters
        ----------
        label: short

        """
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterIUC2ISS2_GetSum(self, label)

    def GetCount(self, label):
        r"""
        GetCount(self, label) -> unsigned long

        Parameters
        ----------
        label: short

        """
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterIUC2ISS2_GetCount(self, label)

    def GetHistogram(self, label):
        r"""
        GetHistogram(self, label) -> itkHistogramD_Pointer

        Parameters
        ----------
        label: short

        """
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterIUC2ISS2_GetHistogram(self, label)

    def SetHistogramParameters(self, numBins, lowerBound, upperBound):
        r"""
        SetHistogramParameters(self, numBins, lowerBound, upperBound)

        Parameters
        ----------
        numBins: int const
        lowerBound: double
        upperBound: double

        """
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterIUC2ISS2_SetHistogramParameters(self, numBins, lowerBound, upperBound)

    def SetNumberOfStreamDivisions(self, n):
        r"""
        SetNumberOfStreamDivisions(self, n)

        Parameters
        ----------
        n: unsigned int const

        """
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterIUC2ISS2_SetNumberOfStreamDivisions(self, n)

    def GetNumberOfStreamDivisions(self):
        r"""GetNumberOfStreamDivisions(self) -> unsigned int"""
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterIUC2ISS2_GetNumberOfStreamDivisions(self)
    InputHasNumericTraitsCheck = _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterIUC2ISS2_InputHasNumericTraitsCheck
    
    __swig_destroy__ = _itkLabelStatisticsImageFilterPython.delete_itkLabelStatisticsImageFilterIUC2ISS2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkLabelStatisticsImageFilterIUC2ISS2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterIUC2ISS2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkLabelStatisticsImageFilterIUC2ISS2

        Create a new object of the class itkLabelStatisticsImageFilterIUC2ISS2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkLabelStatisticsImageFilterIUC2ISS2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkLabelStatisticsImageFilterIUC2ISS2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkLabelStatisticsImageFilterIUC2ISS2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkLabelStatisticsImageFilterIUC2ISS2 in _itkLabelStatisticsImageFilterPython:
_itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterIUC2ISS2_swigregister(itkLabelStatisticsImageFilterIUC2ISS2)

def itkLabelStatisticsImageFilterIUC2IUC2_New():
    return itkLabelStatisticsImageFilterIUC2IUC2.New()

class itkLabelStatisticsImageFilterIUC2IUC2(itk.itkImageSinkPython.itkImageSinkIUC2):
    r"""Proxy of C++ itkLabelStatisticsImageFilterIUC2IUC2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkLabelStatisticsImageFilterIUC2IUC2_Pointer"""
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterIUC2IUC2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkLabelStatisticsImageFilterIUC2IUC2_Pointer"""
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterIUC2IUC2_Clone(self)

    def SetUseHistograms(self, _arg):
        r"""
        SetUseHistograms(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterIUC2IUC2_SetUseHistograms(self, _arg)

    def GetUseHistograms(self):
        r"""GetUseHistograms(self) -> bool"""
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterIUC2IUC2_GetUseHistograms(self)

    def UseHistogramsOn(self):
        r"""UseHistogramsOn(self)"""
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterIUC2IUC2_UseHistogramsOn(self)

    def UseHistogramsOff(self):
        r"""UseHistogramsOff(self)"""
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterIUC2IUC2_UseHistogramsOff(self)

    def GetValidLabelValues(self):
        r"""GetValidLabelValues(self) -> vectorUC"""
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterIUC2IUC2_GetValidLabelValues(self)

    def SetLabelInput(self, _arg):
        r"""
        SetLabelInput(self, _arg)

        Parameters
        ----------
        _arg: itkImageUC2 const *

        """
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterIUC2IUC2_SetLabelInput(self, _arg)

    def GetLabelInput(self):
        r"""GetLabelInput(self) -> itkImageUC2"""
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterIUC2IUC2_GetLabelInput(self)

    def HasLabel(self, label):
        r"""
        HasLabel(self, label) -> bool

        Parameters
        ----------
        label: unsigned char

        """
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterIUC2IUC2_HasLabel(self, label)

    def GetNumberOfObjects(self):
        r"""GetNumberOfObjects(self) -> unsigned long"""
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterIUC2IUC2_GetNumberOfObjects(self)

    def GetNumberOfLabels(self):
        r"""GetNumberOfLabels(self) -> unsigned long"""
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterIUC2IUC2_GetNumberOfLabels(self)

    def GetMinimum(self, label):
        r"""
        GetMinimum(self, label) -> double

        Parameters
        ----------
        label: unsigned char

        """
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterIUC2IUC2_GetMinimum(self, label)

    def GetMaximum(self, label):
        r"""
        GetMaximum(self, label) -> double

        Parameters
        ----------
        label: unsigned char

        """
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterIUC2IUC2_GetMaximum(self, label)

    def GetMean(self, label):
        r"""
        GetMean(self, label) -> double

        Parameters
        ----------
        label: unsigned char

        """
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterIUC2IUC2_GetMean(self, label)

    def GetMedian(self, label):
        r"""
        GetMedian(self, label) -> double

        Parameters
        ----------
        label: unsigned char

        """
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterIUC2IUC2_GetMedian(self, label)

    def GetSigma(self, label):
        r"""
        GetSigma(self, label) -> double

        Parameters
        ----------
        label: unsigned char

        """
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterIUC2IUC2_GetSigma(self, label)

    def GetVariance(self, label):
        r"""
        GetVariance(self, label) -> double

        Parameters
        ----------
        label: unsigned char

        """
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterIUC2IUC2_GetVariance(self, label)

    def GetBoundingBox(self, label):
        r"""
        GetBoundingBox(self, label) -> vectorSL

        Parameters
        ----------
        label: unsigned char

        """
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterIUC2IUC2_GetBoundingBox(self, label)

    def GetRegion(self, label):
        r"""
        GetRegion(self, label) -> itkImageRegion2

        Parameters
        ----------
        label: unsigned char

        """
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterIUC2IUC2_GetRegion(self, label)

    def GetSum(self, label):
        r"""
        GetSum(self, label) -> double

        Parameters
        ----------
        label: unsigned char

        """
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterIUC2IUC2_GetSum(self, label)

    def GetCount(self, label):
        r"""
        GetCount(self, label) -> unsigned long

        Parameters
        ----------
        label: unsigned char

        """
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterIUC2IUC2_GetCount(self, label)

    def GetHistogram(self, label):
        r"""
        GetHistogram(self, label) -> itkHistogramD_Pointer

        Parameters
        ----------
        label: unsigned char

        """
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterIUC2IUC2_GetHistogram(self, label)

    def SetHistogramParameters(self, numBins, lowerBound, upperBound):
        r"""
        SetHistogramParameters(self, numBins, lowerBound, upperBound)

        Parameters
        ----------
        numBins: int const
        lowerBound: double
        upperBound: double

        """
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterIUC2IUC2_SetHistogramParameters(self, numBins, lowerBound, upperBound)

    def SetNumberOfStreamDivisions(self, n):
        r"""
        SetNumberOfStreamDivisions(self, n)

        Parameters
        ----------
        n: unsigned int const

        """
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterIUC2IUC2_SetNumberOfStreamDivisions(self, n)

    def GetNumberOfStreamDivisions(self):
        r"""GetNumberOfStreamDivisions(self) -> unsigned int"""
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterIUC2IUC2_GetNumberOfStreamDivisions(self)
    InputHasNumericTraitsCheck = _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterIUC2IUC2_InputHasNumericTraitsCheck
    
    __swig_destroy__ = _itkLabelStatisticsImageFilterPython.delete_itkLabelStatisticsImageFilterIUC2IUC2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkLabelStatisticsImageFilterIUC2IUC2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterIUC2IUC2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkLabelStatisticsImageFilterIUC2IUC2

        Create a new object of the class itkLabelStatisticsImageFilterIUC2IUC2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkLabelStatisticsImageFilterIUC2IUC2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkLabelStatisticsImageFilterIUC2IUC2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkLabelStatisticsImageFilterIUC2IUC2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkLabelStatisticsImageFilterIUC2IUC2 in _itkLabelStatisticsImageFilterPython:
_itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterIUC2IUC2_swigregister(itkLabelStatisticsImageFilterIUC2IUC2)

def itkLabelStatisticsImageFilterIUC3ISS3_New():
    return itkLabelStatisticsImageFilterIUC3ISS3.New()

class itkLabelStatisticsImageFilterIUC3ISS3(itk.itkImageSinkPython.itkImageSinkIUC3):
    r"""Proxy of C++ itkLabelStatisticsImageFilterIUC3ISS3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkLabelStatisticsImageFilterIUC3ISS3_Pointer"""
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterIUC3ISS3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkLabelStatisticsImageFilterIUC3ISS3_Pointer"""
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterIUC3ISS3_Clone(self)

    def SetUseHistograms(self, _arg):
        r"""
        SetUseHistograms(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterIUC3ISS3_SetUseHistograms(self, _arg)

    def GetUseHistograms(self):
        r"""GetUseHistograms(self) -> bool"""
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterIUC3ISS3_GetUseHistograms(self)

    def UseHistogramsOn(self):
        r"""UseHistogramsOn(self)"""
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterIUC3ISS3_UseHistogramsOn(self)

    def UseHistogramsOff(self):
        r"""UseHistogramsOff(self)"""
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterIUC3ISS3_UseHistogramsOff(self)

    def GetValidLabelValues(self):
        r"""GetValidLabelValues(self) -> vectorSS"""
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterIUC3ISS3_GetValidLabelValues(self)

    def SetLabelInput(self, _arg):
        r"""
        SetLabelInput(self, _arg)

        Parameters
        ----------
        _arg: itkImageSS3 const *

        """
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterIUC3ISS3_SetLabelInput(self, _arg)

    def GetLabelInput(self):
        r"""GetLabelInput(self) -> itkImageSS3"""
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterIUC3ISS3_GetLabelInput(self)

    def HasLabel(self, label):
        r"""
        HasLabel(self, label) -> bool

        Parameters
        ----------
        label: short

        """
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterIUC3ISS3_HasLabel(self, label)

    def GetNumberOfObjects(self):
        r"""GetNumberOfObjects(self) -> unsigned long"""
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterIUC3ISS3_GetNumberOfObjects(self)

    def GetNumberOfLabels(self):
        r"""GetNumberOfLabels(self) -> unsigned long"""
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterIUC3ISS3_GetNumberOfLabels(self)

    def GetMinimum(self, label):
        r"""
        GetMinimum(self, label) -> double

        Parameters
        ----------
        label: short

        """
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterIUC3ISS3_GetMinimum(self, label)

    def GetMaximum(self, label):
        r"""
        GetMaximum(self, label) -> double

        Parameters
        ----------
        label: short

        """
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterIUC3ISS3_GetMaximum(self, label)

    def GetMean(self, label):
        r"""
        GetMean(self, label) -> double

        Parameters
        ----------
        label: short

        """
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterIUC3ISS3_GetMean(self, label)

    def GetMedian(self, label):
        r"""
        GetMedian(self, label) -> double

        Parameters
        ----------
        label: short

        """
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterIUC3ISS3_GetMedian(self, label)

    def GetSigma(self, label):
        r"""
        GetSigma(self, label) -> double

        Parameters
        ----------
        label: short

        """
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterIUC3ISS3_GetSigma(self, label)

    def GetVariance(self, label):
        r"""
        GetVariance(self, label) -> double

        Parameters
        ----------
        label: short

        """
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterIUC3ISS3_GetVariance(self, label)

    def GetBoundingBox(self, label):
        r"""
        GetBoundingBox(self, label) -> vectorSL

        Parameters
        ----------
        label: short

        """
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterIUC3ISS3_GetBoundingBox(self, label)

    def GetRegion(self, label):
        r"""
        GetRegion(self, label) -> itkImageRegion3

        Parameters
        ----------
        label: short

        """
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterIUC3ISS3_GetRegion(self, label)

    def GetSum(self, label):
        r"""
        GetSum(self, label) -> double

        Parameters
        ----------
        label: short

        """
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterIUC3ISS3_GetSum(self, label)

    def GetCount(self, label):
        r"""
        GetCount(self, label) -> unsigned long

        Parameters
        ----------
        label: short

        """
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterIUC3ISS3_GetCount(self, label)

    def GetHistogram(self, label):
        r"""
        GetHistogram(self, label) -> itkHistogramD_Pointer

        Parameters
        ----------
        label: short

        """
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterIUC3ISS3_GetHistogram(self, label)

    def SetHistogramParameters(self, numBins, lowerBound, upperBound):
        r"""
        SetHistogramParameters(self, numBins, lowerBound, upperBound)

        Parameters
        ----------
        numBins: int const
        lowerBound: double
        upperBound: double

        """
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterIUC3ISS3_SetHistogramParameters(self, numBins, lowerBound, upperBound)

    def SetNumberOfStreamDivisions(self, n):
        r"""
        SetNumberOfStreamDivisions(self, n)

        Parameters
        ----------
        n: unsigned int const

        """
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterIUC3ISS3_SetNumberOfStreamDivisions(self, n)

    def GetNumberOfStreamDivisions(self):
        r"""GetNumberOfStreamDivisions(self) -> unsigned int"""
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterIUC3ISS3_GetNumberOfStreamDivisions(self)
    InputHasNumericTraitsCheck = _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterIUC3ISS3_InputHasNumericTraitsCheck
    
    __swig_destroy__ = _itkLabelStatisticsImageFilterPython.delete_itkLabelStatisticsImageFilterIUC3ISS3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkLabelStatisticsImageFilterIUC3ISS3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterIUC3ISS3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkLabelStatisticsImageFilterIUC3ISS3

        Create a new object of the class itkLabelStatisticsImageFilterIUC3ISS3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkLabelStatisticsImageFilterIUC3ISS3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkLabelStatisticsImageFilterIUC3ISS3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkLabelStatisticsImageFilterIUC3ISS3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkLabelStatisticsImageFilterIUC3ISS3 in _itkLabelStatisticsImageFilterPython:
_itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterIUC3ISS3_swigregister(itkLabelStatisticsImageFilterIUC3ISS3)

def itkLabelStatisticsImageFilterIUC3IUC3_New():
    return itkLabelStatisticsImageFilterIUC3IUC3.New()

class itkLabelStatisticsImageFilterIUC3IUC3(itk.itkImageSinkPython.itkImageSinkIUC3):
    r"""Proxy of C++ itkLabelStatisticsImageFilterIUC3IUC3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkLabelStatisticsImageFilterIUC3IUC3_Pointer"""
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterIUC3IUC3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkLabelStatisticsImageFilterIUC3IUC3_Pointer"""
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterIUC3IUC3_Clone(self)

    def SetUseHistograms(self, _arg):
        r"""
        SetUseHistograms(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterIUC3IUC3_SetUseHistograms(self, _arg)

    def GetUseHistograms(self):
        r"""GetUseHistograms(self) -> bool"""
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterIUC3IUC3_GetUseHistograms(self)

    def UseHistogramsOn(self):
        r"""UseHistogramsOn(self)"""
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterIUC3IUC3_UseHistogramsOn(self)

    def UseHistogramsOff(self):
        r"""UseHistogramsOff(self)"""
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterIUC3IUC3_UseHistogramsOff(self)

    def GetValidLabelValues(self):
        r"""GetValidLabelValues(self) -> vectorUC"""
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterIUC3IUC3_GetValidLabelValues(self)

    def SetLabelInput(self, _arg):
        r"""
        SetLabelInput(self, _arg)

        Parameters
        ----------
        _arg: itkImageUC3 const *

        """
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterIUC3IUC3_SetLabelInput(self, _arg)

    def GetLabelInput(self):
        r"""GetLabelInput(self) -> itkImageUC3"""
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterIUC3IUC3_GetLabelInput(self)

    def HasLabel(self, label):
        r"""
        HasLabel(self, label) -> bool

        Parameters
        ----------
        label: unsigned char

        """
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterIUC3IUC3_HasLabel(self, label)

    def GetNumberOfObjects(self):
        r"""GetNumberOfObjects(self) -> unsigned long"""
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterIUC3IUC3_GetNumberOfObjects(self)

    def GetNumberOfLabels(self):
        r"""GetNumberOfLabels(self) -> unsigned long"""
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterIUC3IUC3_GetNumberOfLabels(self)

    def GetMinimum(self, label):
        r"""
        GetMinimum(self, label) -> double

        Parameters
        ----------
        label: unsigned char

        """
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterIUC3IUC3_GetMinimum(self, label)

    def GetMaximum(self, label):
        r"""
        GetMaximum(self, label) -> double

        Parameters
        ----------
        label: unsigned char

        """
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterIUC3IUC3_GetMaximum(self, label)

    def GetMean(self, label):
        r"""
        GetMean(self, label) -> double

        Parameters
        ----------
        label: unsigned char

        """
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterIUC3IUC3_GetMean(self, label)

    def GetMedian(self, label):
        r"""
        GetMedian(self, label) -> double

        Parameters
        ----------
        label: unsigned char

        """
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterIUC3IUC3_GetMedian(self, label)

    def GetSigma(self, label):
        r"""
        GetSigma(self, label) -> double

        Parameters
        ----------
        label: unsigned char

        """
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterIUC3IUC3_GetSigma(self, label)

    def GetVariance(self, label):
        r"""
        GetVariance(self, label) -> double

        Parameters
        ----------
        label: unsigned char

        """
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterIUC3IUC3_GetVariance(self, label)

    def GetBoundingBox(self, label):
        r"""
        GetBoundingBox(self, label) -> vectorSL

        Parameters
        ----------
        label: unsigned char

        """
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterIUC3IUC3_GetBoundingBox(self, label)

    def GetRegion(self, label):
        r"""
        GetRegion(self, label) -> itkImageRegion3

        Parameters
        ----------
        label: unsigned char

        """
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterIUC3IUC3_GetRegion(self, label)

    def GetSum(self, label):
        r"""
        GetSum(self, label) -> double

        Parameters
        ----------
        label: unsigned char

        """
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterIUC3IUC3_GetSum(self, label)

    def GetCount(self, label):
        r"""
        GetCount(self, label) -> unsigned long

        Parameters
        ----------
        label: unsigned char

        """
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterIUC3IUC3_GetCount(self, label)

    def GetHistogram(self, label):
        r"""
        GetHistogram(self, label) -> itkHistogramD_Pointer

        Parameters
        ----------
        label: unsigned char

        """
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterIUC3IUC3_GetHistogram(self, label)

    def SetHistogramParameters(self, numBins, lowerBound, upperBound):
        r"""
        SetHistogramParameters(self, numBins, lowerBound, upperBound)

        Parameters
        ----------
        numBins: int const
        lowerBound: double
        upperBound: double

        """
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterIUC3IUC3_SetHistogramParameters(self, numBins, lowerBound, upperBound)

    def SetNumberOfStreamDivisions(self, n):
        r"""
        SetNumberOfStreamDivisions(self, n)

        Parameters
        ----------
        n: unsigned int const

        """
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterIUC3IUC3_SetNumberOfStreamDivisions(self, n)

    def GetNumberOfStreamDivisions(self):
        r"""GetNumberOfStreamDivisions(self) -> unsigned int"""
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterIUC3IUC3_GetNumberOfStreamDivisions(self)
    InputHasNumericTraitsCheck = _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterIUC3IUC3_InputHasNumericTraitsCheck
    
    __swig_destroy__ = _itkLabelStatisticsImageFilterPython.delete_itkLabelStatisticsImageFilterIUC3IUC3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkLabelStatisticsImageFilterIUC3IUC3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterIUC3IUC3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkLabelStatisticsImageFilterIUC3IUC3

        Create a new object of the class itkLabelStatisticsImageFilterIUC3IUC3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkLabelStatisticsImageFilterIUC3IUC3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkLabelStatisticsImageFilterIUC3IUC3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkLabelStatisticsImageFilterIUC3IUC3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkLabelStatisticsImageFilterIUC3IUC3 in _itkLabelStatisticsImageFilterPython:
_itkLabelStatisticsImageFilterPython.itkLabelStatisticsImageFilterIUC3IUC3_swigregister(itkLabelStatisticsImageFilterIUC3IUC3)

from itk.support import helpers
import itk.support.types as itkt
from typing import Sequence, Tuple, Union

@helpers.accept_array_like_xarray_torch
def label_statistics_image_filter(*args: itkt.ImageLike,  use_histograms: bool=..., label_input: itkt.Image=..., histogram_parameters: int=..., number_of_stream_divisions: int=...,**kwargs):
    """Functional interface for LabelStatisticsImageFilter"""
    import itk

    kwarg_typehints = { 'use_histograms':use_histograms,'label_input':label_input,'histogram_parameters':histogram_parameters,'number_of_stream_divisions':number_of_stream_divisions }
    specified_kwarg_typehints = { k:v for (k,v) in kwarg_typehints.items() if kwarg_typehints[k] is not ... }
    kwargs.update(specified_kwarg_typehints)


    instance = itk.LabelStatisticsImageFilter.New(*args, **kwargs)

    return instance.__internal_call__()

def label_statistics_image_filter_init_docstring():
    import itk
    from itk.support import template_class

    filter_class = itk.ITKImageStatistics.LabelStatisticsImageFilter
    label_statistics_image_filter.process_object = filter_class
    is_template = isinstance(filter_class, template_class.itkTemplate)
    if is_template:
        filter_object = filter_class.values()[0]
    else:
        filter_object = filter_class

    label_statistics_image_filter.__doc__ = filter_object.__doc__



